@@ -6,7 +6,9 @@ import sys, os, json, logging, arrow, codecs
 
 from datetime import datetime
 from uuid import uuid4
+
 from docx import Document
+from docx.shared import Inches
 
 from Baubles.Logger import Logger
 from Perdy.pretty import prettyPrint
@@ -198,7 +200,9 @@ class COD(object):
 						if checkboxes else '  '*depth, note,
 						self.xcolours['Off'],
 					))
-					docx.add_paragraph(note)
+					indent = Inches(depth*0.25)
+					docx.add_paragraph(note).paragraph_format.left_indent = indent
+
 
 		for grandChild in getElements(cod.ctx, 'ChildItem', childItem):
 			self.__node2docx(
@@ -245,6 +249,15 @@ class COD(object):
 
 		docx = Document()
 
+		p = re.compile('^Heading (\d)$')
+
+		for style in docx.styles:
+			m =  p.match(style.name)
+			if m:
+				depth = int(m.group(1))
+				indent = Inches(depth*0.25)
+				style.paragraph_format.left_indent = indent
+
 		if blackAndWhite:
 			for key in list(self.xcolours.keys()):
 				self.xcolours[key] = ''
